<?php

if ( !defined('ABSPATH') ) {
	header( 'HTTP/1.0 403 Forbidden' );
	die;
}


if ( ! class_exists( 'PurdueCPT_Settings_Page' ) ) :
/* Best Practices Settings Page */
class PurdueCPT_Settings_Page {
	private $_types;

	public function __construct($types) {
		$this->_types = $types; // Set Available Post Types

		add_action( 'admin_menu', array( $this, 'create_settings' ) );
		add_action( 'admin_init', array( $this, 'setup_sections' ) );
		add_action( 'admin_init', array( $this, 'setup_fields' ) );
	}

	public function create_settings() {
		$page_title = 'Custom Post Types Settings';
		$menu_title = 'Purdue Post Types';
		$capability = 'manage_options';
		$slug = 'purduecpt';
		$callback = array($this, 'settings_content');
		add_options_page($page_title, $menu_title, $capability, $slug, $callback);
	}

	public function settings_content() { ?>
		<div class="wrap">
			<h1>Enable Custom Post Types</h1>
			<?php /* settings_errors(); */ ?>
			<form method="POST" action="options.php">
				<?php
					settings_fields( 'purduecpt' );
					do_settings_sections( 'purduecpt' );
					submit_button();
				?>
			</form>
		</div> <?php

		// refresh permalinks if changes occured
		flush_rewrite_rules();
	}

	public function setup_sections() {
		add_settings_section( 'purduecpt_section', 'Enable various custom post types used by Purdue University', array(), 'purduecpt' );
	}

	public function setup_fields() {
		$fields = array(
			array(
				'label' => 'Case Study Post Type',
				'id' => 'purdue-casestudies-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Content Package Post Type',
				'id' => 'purdue-contentpkg-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			), 
			array(
				'label' => 'Events Post Type',
				'id' => 'purdue-event-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Faculty Post Type',
				'id' => 'purdue-faculty-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Publication Post Type',
				'id' => 'purdue-publication-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Templates Post Type',
				'id' => 'purdue-templates-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Tips of the Week Post Type',
				'id' => 'purdue-tips-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Purdue in the news',
				'id' => 'purdue-newsList-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
			array(
				'label' => 'Earned Media',
				'id' => 'purdue-earnedMedia-cpt',
				'type' => 'checkbox',
				'section' => 'purduecpt_section',
				'options' => array(
					'Enable' => 'Enable',
				),
				'desc' => '',
			),
		);

		$default = array(
			'label' => 'Case Study Post Type',
			'id' => 'purdue-casestudies-cpt',
			'type' => 'checkbox',
			'section' => 'purduecpt_section',
			'options' => array(
				'Enable' => 'Enable',
			),
			'desc' => '',
		);

		foreach( $this->_types as $class ){
			$field = array_merge($default, array( 'label' => $class['name'] . ' Post Type', 'id' => 'purdue-' . $class['slug'] . '-cpt'));

			add_settings_field( $field['id'], $field['label'], array( $this, 'field_callback' ), 'purduecpt', $field['section'], $field );
			register_setting( 'purduecpt', $field['id'] );
		}
	}

	public function field_callback( $field ) {
		
		if(is_array(get_option( $field['id'] )) && ! empty ( $field['id'] )){
			$value = get_option( $field['id'] );
		}else{
			$value=[""];
		}
		
		// var_dump(get_option( $field['id'] ));
		switch ( $field['type'] ) {
				case 'radio':
				case 'checkbox':
					if( ! empty ( $field['options'] ) && is_array( $field['options'] ) ) {
						$options_markup = '';
						$iterator = 0;
						foreach( $field['options'] as $key => $label ) {
							$iterator++;			
							$options_markup.= sprintf('<label for="%1$s_%6$s"><input id="%1$s_%6$s" name="%1$s[]" type="%2$s" value="%3$s" %4$s /> %5$s</label><br/>',
							$field['id'],
							$field['type'],
							$key,
							checked($value[array_search($key, [$value], true)], $key, false),
							$label,
							$iterator
							);
							}
							printf( '<fieldset>%s</fieldset>',
							$options_markup
							);
					}
					break;
			default:
				printf( '<input name="%1$s" id="%1$s" type="%2$s" placeholder="%3$s" value="%4$s" />',
					$field['id'],
					$field['type'],
					$field['placeholder'],
					$value
				);
		}
		if( $desc = $field['desc'] ) {
			printf( '<p class="description">%s </p>', $desc );
		}
	}
}


endif;
